Class: Aws::LookoutMetrics::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::LookoutMetrics::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-lookoutmetrics/client.rb
Overview
An API client for LookoutMetrics. To construct a client, you need to configure a :region and :credentials.
client = Aws::LookoutMetrics::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#activate_anomaly_detector(params = {}) ⇒ Struct
Activates an anomaly detector.
-
#back_test_anomaly_detector(params = {}) ⇒ Struct
Runs a backtest for anomaly detection for the specified resource.
-
#create_alert(params = {}) ⇒ Types::CreateAlertResponse
Creates an alert for an anomaly detector.
-
#create_anomaly_detector(params = {}) ⇒ Types::CreateAnomalyDetectorResponse
Creates an anomaly detector.
-
#create_metric_set(params = {}) ⇒ Types::CreateMetricSetResponse
Creates a dataset.
-
#deactivate_anomaly_detector(params = {}) ⇒ Struct
Deactivates an anomaly detector.
-
#delete_alert(params = {}) ⇒ Struct
Deletes an alert.
-
#delete_anomaly_detector(params = {}) ⇒ Struct
Deletes a detector.
-
#describe_alert(params = {}) ⇒ Types::DescribeAlertResponse
Describes an alert.
-
#describe_anomaly_detection_executions(params = {}) ⇒ Types::DescribeAnomalyDetectionExecutionsResponse
Returns information about the status of the specified anomaly detection jobs.
-
#describe_anomaly_detector(params = {}) ⇒ Types::DescribeAnomalyDetectorResponse
Describes a detector.
-
#describe_metric_set(params = {}) ⇒ Types::DescribeMetricSetResponse
Describes a dataset.
-
#detect_metric_set_config(params = {}) ⇒ Types::DetectMetricSetConfigResponse
Detects an Amazon S3 dataset's file format, interval, and offset.
-
#get_anomaly_group(params = {}) ⇒ Types::GetAnomalyGroupResponse
Returns details about a group of anomalous metrics.
-
#get_data_quality_metrics(params = {}) ⇒ Types::GetDataQualityMetricsResponse
Returns details about the requested data quality metrics.
-
#get_feedback(params = {}) ⇒ Types::GetFeedbackResponse
Get feedback for an anomaly group.
-
#get_sample_data(params = {}) ⇒ Types::GetSampleDataResponse
Returns a selection of sample records from an Amazon S3 datasource.
-
#list_alerts(params = {}) ⇒ Types::ListAlertsResponse
Lists the alerts attached to a detector.
-
#list_anomaly_detectors(params = {}) ⇒ Types::ListAnomalyDetectorsResponse
Lists the detectors in the current AWS Region.
-
#list_anomaly_group_related_metrics(params = {}) ⇒ Types::ListAnomalyGroupRelatedMetricsResponse
Returns a list of measures that are potential causes or effects of an anomaly group.
-
#list_anomaly_group_summaries(params = {}) ⇒ Types::ListAnomalyGroupSummariesResponse
Returns a list of anomaly groups.
-
#list_anomaly_group_time_series(params = {}) ⇒ Types::ListAnomalyGroupTimeSeriesResponse
Gets a list of anomalous metrics for a measure in an anomaly group.
-
#list_metric_sets(params = {}) ⇒ Types::ListMetricSetsResponse
Lists the datasets in the current AWS Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of [tags][1] for a detector, dataset, or alert.
-
#put_feedback(params = {}) ⇒ Struct
Add feedback for an anomalous metric.
-
#tag_resource(params = {}) ⇒ Struct
Adds [tags][1] to a detector, dataset, or alert.
-
#untag_resource(params = {}) ⇒ Struct
Removes [tags][1] from a detector, dataset, or alert.
-
#update_alert(params = {}) ⇒ Types::UpdateAlertResponse
Make changes to an existing alert.
-
#update_anomaly_detector(params = {}) ⇒ Types::UpdateAnomalyDetectorResponse
Updates a detector.
-
#update_metric_set(params = {}) ⇒ Types::UpdateMetricSetResponse
Updates a dataset.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2160 2161 2162 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 2160 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2163 2164 2165 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 2163 def errors_module Errors end |
Instance Method Details
#activate_anomaly_detector(params = {}) ⇒ Struct
Activates an anomaly detector.
496 497 498 499 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 496 def activate_anomaly_detector(params = {}, = {}) req = build_request(:activate_anomaly_detector, params) req.send_request() end |
#back_test_anomaly_detector(params = {}) ⇒ Struct
Runs a backtest for anomaly detection for the specified resource.
518 519 520 521 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 518 def back_test_anomaly_detector(params = {}, = {}) req = build_request(:back_test_anomaly_detector, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 2133 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::LookoutMetrics') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-lookoutmetrics' context[:gem_version] = '1.61.0' Seahorse::Client::Request.new(handlers, context) end |
#create_alert(params = {}) ⇒ Types::CreateAlertResponse
Creates an alert for an anomaly detector.
595 596 597 598 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 595 def create_alert(params = {}, = {}) req = build_request(:create_alert, params) req.send_request() end |
#create_anomaly_detector(params = {}) ⇒ Types::CreateAnomalyDetectorResponse
Creates an anomaly detector.
647 648 649 650 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 647 def create_anomaly_detector(params = {}, = {}) req = build_request(:create_anomaly_detector, params) req.send_request() end |
#create_metric_set(params = {}) ⇒ Types::CreateMetricSetResponse
Creates a dataset.
816 817 818 819 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 816 def create_metric_set(params = {}, = {}) req = build_request(:create_metric_set, params) req.send_request() end |
#deactivate_anomaly_detector(params = {}) ⇒ Struct
Deactivates an anomaly detector.
838 839 840 841 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 838 def deactivate_anomaly_detector(params = {}, = {}) req = build_request(:deactivate_anomaly_detector, params) req.send_request() end |
#delete_alert(params = {}) ⇒ Struct
Deletes an alert.
860 861 862 863 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 860 def delete_alert(params = {}, = {}) req = build_request(:delete_alert, params) req.send_request() end |
#delete_anomaly_detector(params = {}) ⇒ Struct
Deletes a detector. Deleting an anomaly detector will delete all of its corresponding resources including any configured datasets and alerts.
884 885 886 887 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 884 def delete_anomaly_detector(params = {}, = {}) req = build_request(:delete_anomaly_detector, params) req.send_request() end |
#describe_alert(params = {}) ⇒ Types::DescribeAlertResponse
Describes an alert.
Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.
936 937 938 939 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 936 def describe_alert(params = {}, = {}) req = build_request(:describe_alert, params) req.send_request() end |
#describe_anomaly_detection_executions(params = {}) ⇒ Types::DescribeAnomalyDetectionExecutionsResponse
Returns information about the status of the specified anomaly detection jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
985 986 987 988 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 985 def describe_anomaly_detection_executions(params = {}, = {}) req = build_request(:describe_anomaly_detection_executions, params) req.send_request() end |
#describe_anomaly_detector(params = {}) ⇒ Types::DescribeAnomalyDetectorResponse
Describes a detector.
Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.
1036 1037 1038 1039 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1036 def describe_anomaly_detector(params = {}, = {}) req = build_request(:describe_anomaly_detector, params) req.send_request() end |
#describe_metric_set(params = {}) ⇒ Types::DescribeMetricSetResponse
Describes a dataset.
Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.
1150 1151 1152 1153 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1150 def describe_metric_set(params = {}, = {}) req = build_request(:describe_metric_set, params) req.send_request() end |
#detect_metric_set_config(params = {}) ⇒ Types::DetectMetricSetConfigResponse
Detects an Amazon S3 dataset's file format, interval, and offset.
1216 1217 1218 1219 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1216 def detect_metric_set_config(params = {}, = {}) req = build_request(:detect_metric_set_config, params) req.send_request() end |
#get_anomaly_group(params = {}) ⇒ Types::GetAnomalyGroupResponse
Returns details about a group of anomalous metrics.
1260 1261 1262 1263 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1260 def get_anomaly_group(params = {}, = {}) req = build_request(:get_anomaly_group, params) req.send_request() end |
#get_data_quality_metrics(params = {}) ⇒ Types::GetDataQualityMetricsResponse
Returns details about the requested data quality metrics.
1301 1302 1303 1304 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1301 def get_data_quality_metrics(params = {}, = {}) req = build_request(:get_data_quality_metrics, params) req.send_request() end |
#get_feedback(params = {}) ⇒ Types::GetFeedbackResponse
Get feedback for an anomaly group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1351 1352 1353 1354 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1351 def get_feedback(params = {}, = {}) req = build_request(:get_feedback, params) req.send_request() end |
#get_sample_data(params = {}) ⇒ Types::GetSampleDataResponse
Returns a selection of sample records from an Amazon S3 datasource.
1402 1403 1404 1405 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1402 def get_sample_data(params = {}, = {}) req = build_request(:get_sample_data, params) req.send_request() end |
#list_alerts(params = {}) ⇒ Types::ListAlertsResponse
Lists the alerts attached to a detector.
Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1459 1460 1461 1462 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1459 def list_alerts(params = {}, = {}) req = build_request(:list_alerts, params) req.send_request() end |
#list_anomaly_detectors(params = {}) ⇒ Types::ListAnomalyDetectorsResponse
Lists the detectors in the current AWS Region.
Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1510 1511 1512 1513 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1510 def list_anomaly_detectors(params = {}, = {}) req = build_request(:list_anomaly_detectors, params) req.send_request() end |
#list_anomaly_group_related_metrics(params = {}) ⇒ Types::ListAnomalyGroupRelatedMetricsResponse
Returns a list of measures that are potential causes or effects of an anomaly group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1566 1567 1568 1569 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1566 def (params = {}, = {}) req = build_request(:list_anomaly_group_related_metrics, params) req.send_request() end |
#list_anomaly_group_summaries(params = {}) ⇒ Types::ListAnomalyGroupSummariesResponse
Returns a list of anomaly groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1622 1623 1624 1625 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1622 def list_anomaly_group_summaries(params = {}, = {}) req = build_request(:list_anomaly_group_summaries, params) req.send_request() end |
#list_anomaly_group_time_series(params = {}) ⇒ Types::ListAnomalyGroupTimeSeriesResponse
Gets a list of anomalous metrics for a measure in an anomaly group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1684 1685 1686 1687 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1684 def list_anomaly_group_time_series(params = {}, = {}) req = build_request(:list_anomaly_group_time_series, params) req.send_request() end |
#list_metric_sets(params = {}) ⇒ Types::ListMetricSetsResponse
Lists the datasets in the current AWS Region.
Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1739 1740 1741 1742 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1739 def list_metric_sets(params = {}, = {}) req = build_request(:list_metric_sets, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of tags for a detector, dataset, or alert.
1772 1773 1774 1775 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1772 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_feedback(params = {}) ⇒ Struct
Add feedback for an anomalous metric.
1802 1803 1804 1805 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1802 def put_feedback(params = {}, = {}) req = build_request(:put_feedback, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a detector, dataset, or alert.
1835 1836 1837 1838 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1835 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a detector, dataset, or alert.
1865 1866 1867 1868 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1865 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_alert(params = {}) ⇒ Types::UpdateAlertResponse
Make changes to an existing alert.
1928 1929 1930 1931 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1928 def update_alert(params = {}, = {}) req = build_request(:update_alert, params) req.send_request() end |
#update_anomaly_detector(params = {}) ⇒ Types::UpdateAnomalyDetectorResponse
Updates a detector. After activation, you can only change a detector's ingestion delay and description.
1972 1973 1974 1975 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 1972 def update_anomaly_detector(params = {}, = {}) req = build_request(:update_anomaly_detector, params) req.send_request() end |
#update_metric_set(params = {}) ⇒ Types::UpdateMetricSetResponse
Updates a dataset.
2124 2125 2126 2127 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 2124 def update_metric_set(params = {}, = {}) req = build_request(:update_metric_set, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2153 2154 2155 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 2153 def waiter_names [] end |