Class: Aws::LookoutMetrics::Types::Alert

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lookoutmetrics/types.rb

Overview

A configuration for Amazon SNS-integrated notifications.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action ⇒ Types::Action

Action that will be triggered when there is an alert.

Returns:



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/aws-sdk-lookoutmetrics/types.rb', line 111

class Alert < Struct.new(
  :action,
  :alert_description,
  :alert_arn,
  :anomaly_detector_arn,
  :alert_name,
  :alert_sensitivity_threshold,
  :alert_type,
  :alert_status,
  :last_modification_time,
  :creation_time,
  :alert_filters)
  SENSITIVE = []
  include Aws::Structure
end

#alert_arn ⇒ String

The ARN of the alert.

Returns:



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/aws-sdk-lookoutmetrics/types.rb', line 111

class Alert < Struct.new(
  :action,
  :alert_description,
  :alert_arn,
  :anomaly_detector_arn,
  :alert_name,
  :alert_sensitivity_threshold,
  :alert_type,
  :alert_status,
  :last_modification_time,
  :creation_time,
  :alert_filters)
  SENSITIVE = []
  include Aws::Structure
end

#alert_description ⇒ String

A description of the alert.

Returns:



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/aws-sdk-lookoutmetrics/types.rb', line 111

class Alert < Struct.new(
  :action,
  :alert_description,
  :alert_arn,
  :anomaly_detector_arn,
  :alert_name,
  :alert_sensitivity_threshold,
  :alert_type,
  :alert_status,
  :last_modification_time,
  :creation_time,
  :alert_filters)
  SENSITIVE = []
  include Aws::Structure
end

#alert_filters ⇒ Types::AlertFilters

The configuration of the alert filters, containing MetricList and DimensionFilter.

Returns:



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/aws-sdk-lookoutmetrics/types.rb', line 111

class Alert < Struct.new(
  :action,
  :alert_description,
  :alert_arn,
  :anomaly_detector_arn,
  :alert_name,
  :alert_sensitivity_threshold,
  :alert_type,
  :alert_status,
  :last_modification_time,
  :creation_time,
  :alert_filters)
  SENSITIVE = []
  include Aws::Structure
end

#alert_name ⇒ String

The name of the alert.

Returns:



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/aws-sdk-lookoutmetrics/types.rb', line 111

class Alert < Struct.new(
  :action,
  :alert_description,
  :alert_arn,
  :anomaly_detector_arn,
  :alert_name,
  :alert_sensitivity_threshold,
  :alert_type,
  :alert_status,
  :last_modification_time,
  :creation_time,
  :alert_filters)
  SENSITIVE = []
  include Aws::Structure
end

#alert_sensitivity_threshold ⇒ Integer

The minimum severity for an anomaly to trigger the alert.

Returns:



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/aws-sdk-lookoutmetrics/types.rb', line 111

class Alert < Struct.new(
  :action,
  :alert_description,
  :alert_arn,
  :anomaly_detector_arn,
  :alert_name,
  :alert_sensitivity_threshold,
  :alert_type,
  :alert_status,
  :last_modification_time,
  :creation_time,
  :alert_filters)
  SENSITIVE = []
  include Aws::Structure
end

#alert_status ⇒ String

The status of the alert.

Returns:



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/aws-sdk-lookoutmetrics/types.rb', line 111

class Alert < Struct.new(
  :action,
  :alert_description,
  :alert_arn,
  :anomaly_detector_arn,
  :alert_name,
  :alert_sensitivity_threshold,
  :alert_type,
  :alert_status,
  :last_modification_time,
  :creation_time,
  :alert_filters)
  SENSITIVE = []
  include Aws::Structure
end

#alert_type ⇒ String

The type of the alert.

Returns:



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/aws-sdk-lookoutmetrics/types.rb', line 111

class Alert < Struct.new(
  :action,
  :alert_description,
  :alert_arn,
  :anomaly_detector_arn,
  :alert_name,
  :alert_sensitivity_threshold,
  :alert_type,
  :alert_status,
  :last_modification_time,
  :creation_time,
  :alert_filters)
  SENSITIVE = []
  include Aws::Structure
end

#anomaly_detector_arn ⇒ String

The ARN of the detector to which the alert is attached.

Returns:



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/aws-sdk-lookoutmetrics/types.rb', line 111

class Alert < Struct.new(
  :action,
  :alert_description,
  :alert_arn,
  :anomaly_detector_arn,
  :alert_name,
  :alert_sensitivity_threshold,
  :alert_type,
  :alert_status,
  :last_modification_time,
  :creation_time,
  :alert_filters)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time ⇒ Time

The time at which the alert was created.

Returns:



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/aws-sdk-lookoutmetrics/types.rb', line 111

class Alert < Struct.new(
  :action,
  :alert_description,
  :alert_arn,
  :anomaly_detector_arn,
  :alert_name,
  :alert_sensitivity_threshold,
  :alert_type,
  :alert_status,
  :last_modification_time,
  :creation_time,
  :alert_filters)
  SENSITIVE = []
  include Aws::Structure
end

#last_modification_time ⇒ Time

The time at which the alert was last modified.

Returns:



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/aws-sdk-lookoutmetrics/types.rb', line 111

class Alert < Struct.new(
  :action,
  :alert_description,
  :alert_arn,
  :anomaly_detector_arn,
  :alert_name,
  :alert_sensitivity_threshold,
  :alert_type,
  :alert_status,
  :last_modification_time,
  :creation_time,
  :alert_filters)
  SENSITIVE = []
  include Aws::Structure
end