Class: Aws::LookoutMetrics::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::LookoutMetrics::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-lookoutmetrics/client.rb,
sig/client.rbs
Overview
An API client for LookoutMetrics. To construct a client, you need to configure a :region and :credentials.
client = Aws::LookoutMetrics::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _ActivateAnomalyDetectorResponseSuccess, _BackTestAnomalyDetectorResponseSuccess, _CreateAlertResponseSuccess, _CreateAnomalyDetectorResponseSuccess, _CreateMetricSetResponseSuccess, _DeactivateAnomalyDetectorResponseSuccess, _DeleteAlertResponseSuccess, _DeleteAnomalyDetectorResponseSuccess, _DescribeAlertResponseSuccess, _DescribeAnomalyDetectionExecutionsResponseSuccess, _DescribeAnomalyDetectorResponseSuccess, _DescribeMetricSetResponseSuccess, _DetectMetricSetConfigResponseSuccess, _GetAnomalyGroupResponseSuccess, _GetDataQualityMetricsResponseSuccess, _GetFeedbackResponseSuccess, _GetSampleDataResponseSuccess, _ListAlertsResponseSuccess, _ListAnomalyDetectorsResponseSuccess, _ListAnomalyGroupRelatedMetricsResponseSuccess, _ListAnomalyGroupSummariesResponseSuccess, _ListAnomalyGroupTimeSeriesResponseSuccess, _ListMetricSetsResponseSuccess, _ListTagsForResourceResponseSuccess, _PutFeedbackResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAlertResponseSuccess, _UpdateAnomalyDetectorResponseSuccess, _UpdateMetricSetResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#activate_anomaly_detector(params = {}) ⇒ Struct
Activates an anomaly detector.
-
#back_test_anomaly_detector(params = {}) ⇒ Struct
Runs a backtest for anomaly detection for the specified resource.
-
#create_alert(params = {}) ⇒ Types::CreateAlertResponse
Creates an alert for an anomaly detector.
-
#create_anomaly_detector(params = {}) ⇒ Types::CreateAnomalyDetectorResponse
Creates an anomaly detector.
-
#create_metric_set(params = {}) ⇒ Types::CreateMetricSetResponse
Creates a dataset.
-
#deactivate_anomaly_detector(params = {}) ⇒ Struct
Deactivates an anomaly detector.
-
#delete_alert(params = {}) ⇒ Struct
Deletes an alert.
-
#delete_anomaly_detector(params = {}) ⇒ Struct
Deletes a detector.
-
#describe_alert(params = {}) ⇒ Types::DescribeAlertResponse
Describes an alert.
-
#describe_anomaly_detection_executions(params = {}) ⇒ Types::DescribeAnomalyDetectionExecutionsResponse
Returns information about the status of the specified anomaly detection jobs.
-
#describe_anomaly_detector(params = {}) ⇒ Types::DescribeAnomalyDetectorResponse
Describes a detector.
-
#describe_metric_set(params = {}) ⇒ Types::DescribeMetricSetResponse
Describes a dataset.
-
#detect_metric_set_config(params = {}) ⇒ Types::DetectMetricSetConfigResponse
Detects an Amazon S3 dataset's file format, interval, and offset.
-
#get_anomaly_group(params = {}) ⇒ Types::GetAnomalyGroupResponse
Returns details about a group of anomalous metrics.
-
#get_data_quality_metrics(params = {}) ⇒ Types::GetDataQualityMetricsResponse
Returns details about the requested data quality metrics.
-
#get_feedback(params = {}) ⇒ Types::GetFeedbackResponse
Get feedback for an anomaly group.
-
#get_sample_data(params = {}) ⇒ Types::GetSampleDataResponse
Returns a selection of sample records from an Amazon S3 datasource.
-
#list_alerts(params = {}) ⇒ Types::ListAlertsResponse
Lists the alerts attached to a detector.
-
#list_anomaly_detectors(params = {}) ⇒ Types::ListAnomalyDetectorsResponse
Lists the detectors in the current AWS Region.
-
#list_anomaly_group_related_metrics(params = {}) ⇒ Types::ListAnomalyGroupRelatedMetricsResponse
Returns a list of measures that are potential causes or effects of an anomaly group.
-
#list_anomaly_group_summaries(params = {}) ⇒ Types::ListAnomalyGroupSummariesResponse
Returns a list of anomaly groups.
-
#list_anomaly_group_time_series(params = {}) ⇒ Types::ListAnomalyGroupTimeSeriesResponse
Gets a list of anomalous metrics for a measure in an anomaly group.
-
#list_metric_sets(params = {}) ⇒ Types::ListMetricSetsResponse
Lists the datasets in the current AWS Region.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of [tags][1] for a detector, dataset, or alert.
-
#put_feedback(params = {}) ⇒ Struct
Add feedback for an anomalous metric.
-
#tag_resource(params = {}) ⇒ Struct
Adds [tags][1] to a detector, dataset, or alert.
-
#untag_resource(params = {}) ⇒ Struct
Removes [tags][1] from a detector, dataset, or alert.
-
#update_alert(params = {}) ⇒ Types::UpdateAlertResponse
Make changes to an existing alert.
-
#update_anomaly_detector(params = {}) ⇒ Types::UpdateAnomalyDetectorResponse
Updates a detector.
-
#update_metric_set(params = {}) ⇒ Types::UpdateMetricSetResponse
Updates a dataset.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2160 2161 2162 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 2160 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2163 2164 2165 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 2163 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#activate_anomaly_detector(params = {}) ⇒ Struct
Activates an anomaly detector.
85 |
# File 'sig/client.rbs', line 85
def activate_anomaly_detector: (
|
#back_test_anomaly_detector(params = {}) ⇒ Struct
Runs a backtest for anomaly detection for the specified resource.
94 |
# File 'sig/client.rbs', line 94
def back_test_anomaly_detector: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 2133 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::LookoutMetrics') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-lookoutmetrics' context[:gem_version] = '1.61.0' Seahorse::Client::Request.new(handlers, context) end |
#create_alert(params = {}) ⇒ Types::CreateAlertResponse
Creates an alert for an anomaly detector.
104 |
# File 'sig/client.rbs', line 104
def create_alert: (
|
#create_anomaly_detector(params = {}) ⇒ Types::CreateAnomalyDetectorResponse
Creates an anomaly detector.
138 |
# File 'sig/client.rbs', line 138
def create_anomaly_detector: (
|
#create_metric_set(params = {}) ⇒ Types::CreateMetricSetResponse
Creates a dataset.
154 |
# File 'sig/client.rbs', line 154
def create_metric_set: (
|
#deactivate_anomaly_detector(params = {}) ⇒ Struct
Deactivates an anomaly detector.
260 |
# File 'sig/client.rbs', line 260
def deactivate_anomaly_detector: (
|
#delete_alert(params = {}) ⇒ Struct
Deletes an alert.
269 |
# File 'sig/client.rbs', line 269
def delete_alert: (
|
#delete_anomaly_detector(params = {}) ⇒ Struct
Deletes a detector. Deleting an anomaly detector will delete all of its corresponding resources including any configured datasets and alerts.
278 |
# File 'sig/client.rbs', line 278
def delete_anomaly_detector: (
|
#describe_alert(params = {}) ⇒ Types::DescribeAlertResponse
Describes an alert.
Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.
288 |
# File 'sig/client.rbs', line 288
def describe_alert: (
|
#describe_anomaly_detection_executions(params = {}) ⇒ Types::DescribeAnomalyDetectionExecutionsResponse
Returns information about the status of the specified anomaly detection jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
299 |
# File 'sig/client.rbs', line 299
def describe_anomaly_detection_executions: (
|
#describe_anomaly_detector(params = {}) ⇒ Types::DescribeAnomalyDetectorResponse
Describes a detector.
Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.
321 |
# File 'sig/client.rbs', line 321
def describe_anomaly_detector: (
|
#describe_metric_set(params = {}) ⇒ Types::DescribeMetricSetResponse
Describes a dataset.
Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.
344 |
# File 'sig/client.rbs', line 344
def describe_metric_set: (
|
#detect_metric_set_config(params = {}) ⇒ Types::DetectMetricSetConfigResponse
Detects an Amazon S3 dataset's file format, interval, and offset.
354 |
# File 'sig/client.rbs', line 354
def detect_metric_set_config: (
|
#get_anomaly_group(params = {}) ⇒ Types::GetAnomalyGroupResponse
Returns details about a group of anomalous metrics.
370 |
# File 'sig/client.rbs', line 370
def get_anomaly_group: (
|
#get_data_quality_metrics(params = {}) ⇒ Types::GetDataQualityMetricsResponse
Returns details about the requested data quality metrics.
381 |
# File 'sig/client.rbs', line 381
def get_data_quality_metrics: (
|
#get_feedback(params = {}) ⇒ Types::GetFeedbackResponse
Get feedback for an anomaly group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
393 |
# File 'sig/client.rbs', line 393
def get_feedback: (
|
#get_sample_data(params = {}) ⇒ Types::GetSampleDataResponse
Returns a selection of sample records from an Amazon S3 datasource.
410 |
# File 'sig/client.rbs', line 410
def get_sample_data: (
|
#list_alerts(params = {}) ⇒ Types::ListAlertsResponse
Lists the alerts attached to a detector.
Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
439 |
# File 'sig/client.rbs', line 439
def list_alerts: (
|
#list_anomaly_detectors(params = {}) ⇒ Types::ListAnomalyDetectorsResponse
Lists the detectors in the current AWS Region.
Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
452 |
# File 'sig/client.rbs', line 452
def list_anomaly_detectors: (
|
#list_anomaly_group_related_metrics(params = {}) ⇒ Types::ListAnomalyGroupRelatedMetricsResponse
Returns a list of measures that are potential causes or effects of an anomaly group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
464 |
# File 'sig/client.rbs', line 464
def list_anomaly_group_related_metrics: (
|
#list_anomaly_group_summaries(params = {}) ⇒ Types::ListAnomalyGroupSummariesResponse
Returns a list of anomaly groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
480 |
# File 'sig/client.rbs', line 480
def list_anomaly_group_summaries: (
|
#list_anomaly_group_time_series(params = {}) ⇒ Types::ListAnomalyGroupTimeSeriesResponse
Gets a list of anomalous metrics for a measure in an anomaly group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
497 |
# File 'sig/client.rbs', line 497
def list_anomaly_group_time_series: (
|
#list_metric_sets(params = {}) ⇒ Types::ListMetricSetsResponse
Lists the datasets in the current AWS Region.
Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
512 |
# File 'sig/client.rbs', line 512
def list_metric_sets: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets a list of tags for a detector, dataset, or alert.
524 |
# File 'sig/client.rbs', line 524
def list_tags_for_resource: (
|
#put_feedback(params = {}) ⇒ Struct
Add feedback for an anomalous metric.
533 |
# File 'sig/client.rbs', line 533
def put_feedback: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags to a detector, dataset, or alert.
547 |
# File 'sig/client.rbs', line 547
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a detector, dataset, or alert.
557 |
# File 'sig/client.rbs', line 557
def untag_resource: (
|
#update_alert(params = {}) ⇒ Types::UpdateAlertResponse
Make changes to an existing alert.
568 |
# File 'sig/client.rbs', line 568
def update_alert: (
|
#update_anomaly_detector(params = {}) ⇒ Types::UpdateAnomalyDetectorResponse
Updates a detector. After activation, you can only change a detector's ingestion delay and description.
600 |
# File 'sig/client.rbs', line 600
def update_anomaly_detector: (
|
#update_metric_set(params = {}) ⇒ Types::UpdateMetricSetResponse
Updates a dataset.
615 |
# File 'sig/client.rbs', line 615
def update_metric_set: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2153 2154 2155 |
# File 'lib/aws-sdk-lookoutmetrics/client.rb', line 2153 def waiter_names [] end |